@@ -12,7 +12,7 @@ with 'Catmandu::Fix::SimpleGetValue';
 sub emit_value {
   my ($self, $var) = @_;
 
-  "${var} = Business::ISBN->new(${var})->as_isbn10->as_string if is_value(${var});";
+  "${var} = Business::ISBN->new(${var})->as_isbn10->as_string if is_value(${var}) && length(${var});";
 
 }
 
